pub struct Duration(/* private fields */);Expand description
A signed duration represented as nanoseconds since unix epoch
Implementations
Sourceimpl Duration
impl Duration
pub const MAX: Self
pub const fn from_nanos(nanos: i64) -> Self
pub const fn from_micros(micros: i64) -> Self
pub const fn from_millis(millis: i64) -> Self
pub fn from_secs(secs: impl Into<f64>) -> Self
pub fn as_nanos(&self) -> i64
pub fn as_secs_f32(&self) -> f32
pub fn as_secs_f64(&self) -> f64
Sourcepub fn format_secs(self) -> String
pub fn format_secs(self) -> String
Format as seconds, approximately.
pub fn exact_format(&self, f: &mut Formatter<'_>) -> Result
Sourcepub fn format_subsecond_as_relative(self) -> String
pub fn format_subsecond_as_relative(self) -> String
Useful when showing dates/times on a timeline and you want it compact.
When a duration is less than a second, we only show the time from the last whole second.